@@ -389,8 +389,9 @@ module AP_MODULE_DECLARE_DATA chxj_module;
 
 #define DBG(X,args...)  chxj_log_rerror(APLOG_MARK,APLOG_DEBUG,0,(request_rec*)(X),##args)
 #define SDBG(X,Y)       chxj_log_error(APLOG_MARK,APLOG_DEBUG,0,(X),(Y))
+#define PDBG(X,args...)       ap_log_perror(APLOG_MARK,APLOG_DEBUG,0,(X),##args)
 #define ERR(X,args...)  chxj_log_rerror(APLOG_MARK,APLOG_ERR,0,(X), ##args)
-#define SERR(X,Y)       chxj_log_error(APLOG_MARK,APLOG_ERR,0,(X),(Y))
+#define SERR(X,args...) chxj_log_error(APLOG_MARK,APLOG_ERR,0,(X),##args)
 #define WRN(rec,format,args...)  chxj_log_rerror(APLOG_MARK,APLOG_WARNING,0,(rec),(format), ##args)
 
 extern tag_handlers chxj_tag_handlers[];
@@ -412,6 +413,9 @@ extern char* chxj_node_exchange(
 
 #define IMAGE_CACHE_LIMIT_FMT_LEN  (20)
 
+#define CHXJ_QUERY_STRING_PARAM_PREFIX "_chxj_qs_"
+#define CHXJ_QUERY_STRING_PARAM_PREFIX_ENC "%5Fchxj%5Fqs%5F"
+
 
 #if HAVE_MALLOC == 0
 extern void *rpl_malloc(size_t n);
