@@ -1384,8 +1384,10 @@ s_jhtml_start_form_tag(void *pdoc, Node *node)
     char *q;
     q = strchr(attr_action, '?');
     if (q) {
-      new_hidden_tag = chxj_form_action_to_hidden_tag(doc->pool, attr_action, 0, post_flag);
-      *q = 0;
+      new_hidden_tag = chxj_form_action_to_hidden_tag(r, doc->pool, attr_action, 0, post_flag);
+      if (new_hidden_tag) {
+        *q = 0;
+      }
     }
     W_L(" action=\"");
     W_V(attr_action);
@@ -2517,6 +2519,7 @@ s_jhtml_text_tag(void* pdoc, Node* child)
 
   textval = qs_get_node_value(doc,child);
   if (strlen(textval) == 0) {
+    DBG(r, "end s_jhtml_text_tag()");
     return jhtml->out;
   }
 
