@@ -143,10 +143,10 @@ chxj_headers_fixup(request_rec *r)
   char                *contentType;
   char                *contentLength;
 
-  DBG(r, "REQ[%X] start chxj_headers_fixup()", (apr_size_t)r);
+  DBG(r, "REQ[%X] start chxj_headers_fixup()", (unsigned int)(apr_size_t)r);
   if (r->main) {
-    DBG(r, "REQ[%X] detect internal redirect.", (apr_size_t)r);
-    DBG(r, "REQ[%X] end chxj_headers_fixup()", (apr_size_t)r);
+    DBG(r, "REQ[%X] detect internal redirect.", (unsigned int)(apr_size_t)r);
+    DBG(r, "REQ[%X] end chxj_headers_fixup()", (unsigned int)(apr_size_t)r);
     return DECLINED;
   }
   dconf = chxj_get_module_config(r->per_dir_config, &chxj_module);
@@ -157,8 +157,8 @@ chxj_headers_fixup(request_rec *r)
   contentType = (char *)apr_table_get(r->headers_in, "Content-Type");
   if (contentType
       && strncasecmp("multipart/form-data", contentType, 19) == 0) {
-    DBG(r, "REQ[%X] detect multipart/form-data ==> no target", (apr_size_t)r);
-    DBG(r, "REQ[%X] end chxj_headers_fixup()", (apr_size_t)r);
+    DBG(r, "REQ[%X] detect multipart/form-data ==> no target", (unsigned int)(apr_size_t)r);
+    DBG(r, "REQ[%X] end chxj_headers_fixup()", (unsigned int)(apr_size_t)r);
     return DECLINED;
   }
 
@@ -182,11 +182,11 @@ chxj_headers_fixup(request_rec *r)
   case CHXJ_SPEC_Jhtml:
     entryp = chxj_apply_convrule(r, dconf->convrules);
     if (! entryp) {
-      DBG(r, "REQ[%X] end chxj_headers_fixup() no pattern User-Agent:[%s]", (apr_size_t)r, user_agent);
+      DBG(r, "REQ[%X] end chxj_headers_fixup() no pattern User-Agent:[%s]", (unsigned int)(apr_size_t)r, user_agent);
       return DECLINED;
     }
     if (!entryp || !(entryp->action & CONVRULE_ENGINE_ON_BIT)) {
-      DBG(r,"EngineOff");
+      DBG(r,"REQ[%X] EngineOff", (unsigned int)(apr_size_t)r);
       return DECLINED;
     }
   
@@ -211,7 +211,7 @@ chxj_headers_fixup(request_rec *r)
 
   if (r->method_number == M_POST) {
     if (! apr_table_get(r->headers_in, "X-Chxj-Forward")) {
-        DBG(r, "set Input handler old:[%s] proxyreq:[%d] uri:[%s] filename:[%s]", r->handler, r->proxyreq, r->uri, r->filename);
+        DBG(r, "REQ[%X] set Input handler old:[%s] proxyreq:[%d] uri:[%s] filename:[%s]", (unsigned int)(apr_size_t)r, r->handler, r->proxyreq, r->uri, r->filename);
         r->proxyreq = PROXYREQ_NONE;
         r->handler = apr_psprintf(r->pool, "chxj-input-handler");
     }
@@ -222,8 +222,8 @@ chxj_headers_fixup(request_rec *r)
         apr_status_t rv = apr_sockaddr_info_get(&address, ap_get_server_name(r), APR_UNSPEC, ap_get_server_port(r), 0, r->pool);
         if (rv != APR_SUCCESS) {
           char buf[256];
-          ERR(r, "%s:%d apr_sockaddr_info_get() failed: rv:[%d|%s]", APLOG_MARK, rv, apr_strerror(rv, buf, 256));
-          DBG(r, "end chxj_headers_fixup()");
+          ERR(r, "REQ[%X] %s:%d apr_sockaddr_info_get() failed: rv:[%d|%s]", (unsigned int)(apr_size_t)r, APLOG_MARK, rv, apr_strerror(rv, buf, 256));
+          DBG(r, "REQ[%X] end chxj_headers_fixup()", (unsigned int)(apr_size_t)r);
           return DECLINED;
         }
         char *addr;
@@ -417,10 +417,10 @@ chxj_convert_input_header(request_rec *r,chxjconvrule_entry* entryp)
   cookie_t   *cookie = NULL;
   int        no_update_flag = 0;
 
-  DBG(r, "REQ[%X] start chxj_convert_input_header()", (apr_size_t)r);
+  DBG(r, "REQ[%X] start chxj_convert_input_header()", (unsigned int)(apr_size_t)r);
   if (! r->args) {
-    DBG(r, "REQ[%X] r->args=[null]", (apr_size_t)r);
-    DBG(r, "REQ[%X] end   chxj_convert_input_header()", (apr_size_t)r);
+    DBG(r, "REQ[%X] r->args=[null]", (unsigned int)(apr_size_t)r);
+    DBG(r, "REQ[%X] end   chxj_convert_input_header()", (unsigned int)(apr_size_t)r);
     return 0;
   }
   urilen = strlen(r->args);
@@ -444,13 +444,13 @@ chxj_convert_input_header(request_rec *r,chxjconvrule_entry* entryp)
     value = apr_strtok(NULL, "=", &vstate);
     if (! name) continue;
     if (strcasecmp(name, CHXJ_COOKIE_NOUPDATE_PARAM) == 0 || strcasecmp(name, chxj_url_encode(r->pool, CHXJ_COOKIE_NOUPDATE_PARAM)) == 0) {
-      DBG(r, "REQ[%X] found cookie no update parameter", (apr_size_t)r);
+      DBG(r, "REQ[%X] found cookie no update parameter", (unsigned int)(apr_size_t)r);
       no_update_flag++;
     }
   }
 
   buff = apr_pstrdup(r->pool, r->args);
-  DBG(r, "REQ[%X] r->args=[%s]", (apr_size_t)r, buff);
+  DBG(r, "REQ[%X] r->args=[%s]", (unsigned int)(apr_size_t)r, buff);
 
   /* _chxj_dmy */
   /* _chxj_c_ */
@@ -533,10 +533,10 @@ chxj_convert_input_header(request_rec *r,chxjconvrule_entry* entryp)
       if (! cookie) {
         apr_table_unset(r->headers_in, "Cookie");
         cookie_lock_t *lock = chxj_cookie_lock(r);
-        DBG(r, "REQ[%X] found cookie parameter[%s]", (apr_size_t)r, value);
-        DBG(r, "REQ[%X] call start chxj_load_cookie()",(apr_size_t)r);
+        DBG(r, "REQ[%X] found cookie parameter[%s]", (unsigned int)(apr_size_t)r, value);
+        DBG(r, "REQ[%X] call start chxj_load_cookie()",(unsigned int)(apr_size_t)r);
         cookie = chxj_load_cookie(r, value);
-        DBG(r, "REQ[%X] call end   chxj_load_cookie()",(apr_size_t)r);
+        DBG(r, "REQ[%X] call end   chxj_load_cookie()",(unsigned int)(apr_size_t)r);
         if (! no_update_flag && cookie) {
           cookie = chxj_update_cookie(r, cookie);
         }
@@ -562,8 +562,8 @@ chxj_convert_input_header(request_rec *r,chxjconvrule_entry* entryp)
   }
   r->args = result;
 
-  DBG(r, "REQ[%X] result r->args=[%s]", (apr_size_t)r, r->args);
-  DBG(r, "REQ[%X] end   chxj_convert_input_header()",(apr_size_t)r);
+  DBG(r, "REQ[%X] result r->args=[%s]", (unsigned int)(apr_size_t)r, r->args);
+  DBG(r, "REQ[%X] end   chxj_convert_input_header()",(unsigned int)(apr_size_t)r);
   return 0;
 }
 
@@ -730,10 +730,10 @@ chxj_input_convert(
     if (strcasecmp(name, CHXJ_COOKIE_PARAM) == 0 || strcasecmp(name, "%5Fchxj%5Fcc") == 0) {
       apr_table_unset(r->headers_in, "Cookie");
       cookie_lock_t *lock = chxj_cookie_lock(r);
-      DBG(r, "REQ[%X] found cookie parameter[%s]", (apr_size_t)r, value);
-      DBG(r, "REQ[%X] call start chxj_load_cookie()",(apr_size_t)r);
+      DBG(r, "REQ[%X] found cookie parameter[%s]", (unsigned int)(apr_size_t)r, value);
+      DBG(r, "REQ[%X] call start chxj_load_cookie()",(unsigned int)(apr_size_t)r);
       cookie = chxj_load_cookie(r, value);
-      DBG(r, "REQ[%X] call end   chxj_load_cookie()",(apr_size_t)r);
+      DBG(r, "REQ[%X] call end   chxj_load_cookie()",(unsigned int)(apr_size_t)r);
       if (! no_update_flag && cookie) {
         cookie = chxj_update_cookie(r, cookie);
       }
@@ -784,7 +784,7 @@ chxj_input_convert(
         }
       }
     }
-    DBG(r, "REQ[%X] ************************ name:[%s]", (apr_size_t)r, name);
+    DBG(r, "REQ[%X] ************************ name:[%s]", (unsigned int)(apr_size_t)r, name);
   }
   *len = strlen(result);
   apr_table_setn(r->headers_in, "X-Chxj-Cookie-No-Update", "true");
@@ -792,8 +792,8 @@ chxj_input_convert(
     result = apr_pstrcat(r->pool, result, "&_chxj_nc=true", NULL);
   }
 
-  DBG(r, "REQ[%X] AFTER input convert result = [%s]", (apr_size_t)r, result);
-  DBG(r, "REQ[%X] end chxj_input_convert()", (apr_size_t)r);
+  DBG(r, "REQ[%X] AFTER input convert result = [%s]", (unsigned int)(apr_size_t)r, result);
+  DBG(r, "REQ[%X] end chxj_input_convert()", (unsigned int)(apr_size_t)r);
 
   return result;
 }
@@ -1199,11 +1199,12 @@ chxj_input_handler(request_rec *r)
   char                *response;
   char                *user_agent;
   apr_pool_t          *pool;
+  apr_size_t          ii;
   
-  DBG(r, "REQ[%X] start of chxj_input_handler()", (apr_size_t)r);
+  DBG(r, "REQ[%X] start of chxj_input_handler()", (unsigned int)(apr_size_t)r);
 
   if (strcasecmp(r->handler, "chxj-input-handler")) {
-    DBG(r, "REQ[%X] end chxj_input_handler() (NO chxj-input-handler)", (apr_size_t)r);
+    DBG(r, "REQ[%X] end chxj_input_handler() (NO chxj-input-handler)", (unsigned int)(apr_size_t)r);
     return DECLINED;
   }
   apr_pool_create(&pool, r->pool);
@@ -1237,7 +1238,7 @@ chxj_input_handler(request_rec *r)
   if (post_data_len > 0) {
     post_data = chxj_input_convert(r, (const char**)&post_data, (apr_size_t*)&post_data_len, entryp);
     post_data = apr_pstrcat(r->pool, post_data, "&_chxj_nc=true", NULL);
-    DBG(r, "REQ[%X] (in:exchange)POSTDATA:[%s]", (apr_size_t)r, post_data);
+    DBG(r, "REQ[%X] (in:exchange)POSTDATA:[%s]", (unsigned int)(apr_size_t)r, post_data);
   }
 
   char *url_path;
@@ -1250,14 +1251,19 @@ chxj_input_handler(request_rec *r)
   if (r->args) {
     url_path = apr_pstrcat(pool, url_path, "?", r->args, NULL);
   }
-  DBG(r, "REQ[%X] ==> new url_path:[%s]", (apr_size_t)r, url_path);
+  DBG(r, "REQ[%X] ==> new url_path:[%s]", (unsigned int)(apr_size_t)r, url_path);
 
   apr_size_t res_len;
   apr_table_setn(r->headers_in, CHXJ_HEADER_ORIG_CLIENT_IP, r->connection->remote_ip);
   apr_table_unset(r->headers_in, "Content-Length");
-  apr_table_setn(r->headers_in, "Content-Length", apr_psprintf(pool, "%d", post_data_len));
+  apr_table_setn(r->headers_in, "Content-Length", apr_psprintf(pool, "%" APR_SIZE_T_FMT, post_data_len));
   response = chxj_serf_post(r, pool, url_path, post_data, post_data_len, 1, &res_len);
-  DBG(r, "REQ[%X] response:[%.*s][%d]", (apr_size_t)r, res_len, response, res_len);
+  DBG(r, "REQ[%X] -------------------------------------------------------", (unsigned int)(apr_size_t)r);
+  DBG(r, "REQ[%X] response length:[%" APR_SIZE_T_FMT "]", (unsigned int)(apr_size_t)r, res_len);
+  for (ii=0; ii<res_len/64; ii++) {
+    DBG(r, "REQ[%X] response:[%.*s]", (unsigned int)(apr_size_t)r, 64, &response[ii*64]);
+  }
+  DBG(r, "REQ[%X] -------------------------------------------------------", (unsigned int)(apr_size_t)r);
 
   char *chunked;
   if ((chunked = (char *)apr_table_get(r->headers_out, "Transfer-Encoding")) != NULL) {
@@ -1265,7 +1271,7 @@ chxj_input_handler(request_rec *r)
       r->chunked = 1;  
       apr_table_unset(r->headers_out, "Transfer-Encoding");
     }
-    DBG(r, "REQ[%X] TRANSFER-ENCODING:[%s]",(apr_size_t)r, chunked);
+    DBG(r, "REQ[%X] TRANSFER-ENCODING:[%s]",(unsigned int)(apr_size_t)r, chunked);
   }
   {
     apr_pool_t *wpool;
@@ -1281,13 +1287,13 @@ chxj_input_handler(request_rec *r)
     e = apr_bucket_eos_create(c->bucket_alloc);
     APR_BRIGADE_INSERT_TAIL(bb, e);
     if ((rv = ap_pass_brigade(r->output_filters, bb)) != APR_SUCCESS) {
-      ERR(r, "REQ[%X] %s:%d failed ap_pass_brigade()", (apr_size_t)r, APLOG_MARK);
+      ERR(r, "REQ[%X] %s:%d failed ap_pass_brigade()", (unsigned int)(apr_size_t)r, APLOG_MARK);
       return rv;
     }
     apr_brigade_cleanup(bb);
   }  
 
-  DBG(r, "REQ[%X] end of chxj_input_handler()", (apr_size_t)r);
+  DBG(r, "REQ[%X] end of chxj_input_handler()", (unsigned int)(apr_size_t)r);
   return APR_SUCCESS;
 }
 
@@ -1390,9 +1396,9 @@ static int
 chxj_translate_name(request_rec *r)
 {
   DBG(r, " /*===========================================");
-  DBG(r, " ");
-  DBG(r, " REQ[%X] START REQUEST(uri:[%s])", (apr_size_t)r, r->unparsed_uri);
-  DBG(r, " ");
+  DBG(r, "                                              ");
+  DBG(r, " REQ[%X] START REQUEST(uri:[%s])", (unsigned int)(apr_size_t)r, r->unparsed_uri);
+  DBG(r, "                                              ");
   DBG(r, " *===========================================*/");
   return chxj_trans_name(r);
 }
@@ -1462,10 +1468,10 @@ chxj_insert_filter(request_rec *r)
 
   if (! apr_table_get(r->headers_in, "X-Chxj-Forward")) {
     ap_add_output_filter("chxj_output_filter", ctx, r, r->connection);
-    DBG(r, "added Output Filter");
+    DBG(r, "REQ[%X] added Output Filter", (unsigned int)(apr_size_t)r);
   }
 
-  DBG(r, "end   chxj_insert_filter()");
+  DBG(r, "REQ[%X] end   chxj_insert_filter()", (unsigned int)(apr_size_t)r);
 }
 
 
